(this.webpackJsonpstreamlit_component_template=this.webpackJsonpstreamlit_component_template||[]).push([[0],{17:function(t,e,n){t.exports=n.p+"static/media/magnifying-glass-solid.b713a401.svg"},19:function(t,e,n){t.exports=n(41)},41:function(t,e,n){"use strict";n.r(e);var o=n(4),a=n.n(o),r=n(9),c=n.n(r),i=n(0),s=n(1),p=n(2),u=n(3),l=n(11),h=n(18),m=n(17),f=n.n(m),g=a.a.createElement("img",{width:24,src:f.a,alt:"Search Icon",title:"Search Icon",style:{marginLeft:"6px",marginRight:"6px",padding:"4px"}}),d=function(t){Object(p.a)(n,t);var e=Object(u.a)(n);function n(){var t;Object(s.a)(this,n);for(var o=arguments.length,r=new Array(o),c=0;c<o;c++)r[c]=arguments[c];return(t=e.call.apply(e,[this].concat(r))).state={search:"",option:""},t.onSearchInput=function(e,n){e.length>0&&t.setState({search:e,option:""},(function(){return l.a.setComponentValue(t.state)}))},t.onInputSelection=function(e){t.setState({search:e.value,option:e.value},(function(){return l.a.setComponentValue(t.state)}))},t.render=function(){console.log(t.state),console.log(t.props.args.options);var e=t.state.search!==t.state.option;return a.a.createElement(h.a,{components:{DropdownIndicator:function(){return g}},placeholder:"Search ...",onInputChange:function(e,n){return t.onSearchInput(e,n)},onChange:function(e){return t.onInputSelection(e)},isSearchable:!0,filterOption:function(t,e){return!0},menuIsOpen:e,options:e?t.props.args.options:[]})},t}return Object(i.a)(n)}(l.b),S=Object(l.c)(d);c.a.render(a.a.createElement(a.a.StrictMode,null,a.a.createElement(S,null)),document.getElementById("root"))}},[[19,1,2]]]);
//# sourceMappingURL=main.8ecec752.chunk.js.map