self.__precacheManifest = (self.__precacheManifest || []).concat([
  {
    "revision": "5cd88e98d76a27dd38396bf6f8b26732",
    "url": "./index.html"
  },
  {
    "revision": "ac5acfc51dd686e56dbe",
    "url": "./static/js/2.4537580d.chunk.js"
  },
  {
    "revision": "41b8f9f21f3f055166c2ef8fa2c896e2",
    "url": "./static/js/2.4537580d.chunk.js.LICENSE.txt"
  },
  {
    "revision": "22c2e454e4d85aea63a6",
    "url": "./static/js/main.8ecec752.chunk.js"
  },
  {
    "revision": "7c26bca7e16783d14d15",
    "url": "./static/js/runtime-main.11ec9aca.js"
  },
  {
    "revision": "b713a401735902a95b5940c32ee7b2cf",
    "url": "./static/media/magnifying-glass-solid.b713a401.svg"
  }
]);